@@ -19,6 +19,8 @@ def parse(html: str, show_unclosed_tags: bool = True, strict_parsing: bool = Tru
     :raises WrongHTMLFormatError if wrong format and strict_parsing is True
     """
     parser = MyHTMLParser(auto_close) if strict_parsing else RelaxedHTMLParser()
+    # TODO fix it
+    Node.comments.clear()
     parser.feed(html)
     if strict_parsing:
         if show_unclosed_tags and parser.unclosed_nodes:
